export type HTTPStatusCode = keyof typeof codes;
/**
 * Dictionary of HTTP status codes and their respective message + success flag.
 * @link https://github.com/nodejs/node/blob/master/lib/_http_server.js
 */
export declare const codes: {
    readonly default: readonly ["Default", true];
    readonly '1XX': readonly ["Informational", true];
    readonly 100: readonly ["Continue", true];
    readonly 101: readonly ["Switching Protocols", true];
    readonly 102: readonly ["Processing", true];
    readonly 103: readonly ["Early Hints", true];
    readonly '2XX': readonly ["Success", true];
    readonly 200: readonly ["OK", true];
    readonly 201: readonly ["Created", true];
    readonly 202: readonly ["Accepted", true];
    readonly 203: readonly ["Non-Authoritative Information", true];
    readonly 204: readonly ["No Content", true];
    readonly 205: readonly ["Reset Content", true];
    readonly 206: readonly ["Partial Content", true];
    readonly 207: readonly ["Multi-Status", true];
    readonly 208: readonly ["Already Reported", true];
    readonly 218: readonly ["This is fine", true];
    readonly 226: readonly ["IM Used", true];
    readonly '3XX': readonly ["Redirection", true];
    readonly 300: readonly ["Multiple Choices", true];
    readonly 301: readonly ["Moved Permanently", true];
    readonly 302: readonly ["Found", true];
    readonly 303: readonly ["See Other", true];
    readonly 304: readonly ["Not Modified", true];
    readonly 305: readonly ["Use Proxy", true];
    readonly 306: readonly ["Switch Proxy", true];
    readonly 307: readonly ["Temporary Redirect", true];
    readonly 308: readonly ["Permanent Redirect", true];
    readonly '4XX': readonly ["Client Error", false];
    readonly 400: readonly ["Bad Request", false];
    readonly 401: readonly ["Unauthorized", false];
    readonly 402: readonly ["Payment Required", false];
    readonly 403: readonly ["Forbidden", false];
    readonly 404: readonly ["Not Found", false];
    readonly 405: readonly ["Method Not Allowed", false];
    readonly 406: readonly ["Not Acceptable", false];
    readonly 407: readonly ["Proxy Authentication Required", false];
    readonly 408: readonly ["Request Timeout", false];
    readonly 409: readonly ["Conflict", false];
    readonly 410: readonly ["Gone", false];
    readonly 411: readonly ["Length Required", false];
    readonly 412: readonly ["Precondition Failed", false];
    readonly 413: readonly ["Payload Too Large", false];
    readonly 414: readonly ["URI Too Long", false];
    readonly 415: readonly ["Unsupported Media Type", false];
    readonly 416: readonly ["Range Not Satisfiable", false];
    readonly 417: readonly ["Expectation Failed", false];
    readonly 418: readonly ["I'm a teapot", false];
    readonly 419: readonly ["Page Expired", false];
    readonly 420: readonly ["Enhance Your Calm", false];
    readonly 421: readonly ["Misdirected Request", false];
    readonly 422: readonly ["Unprocessable Entity", false];
    readonly 423: readonly ["Locked", false];
    readonly 424: readonly ["Failed Dependency", false];
    readonly 425: readonly ["Too Early", false];
    readonly 426: readonly ["Upgrade Required", false];
    readonly 428: readonly ["Precondition Required", false];
    readonly 429: readonly ["Too Many Requests", false];
    readonly 430: readonly ["Request Header Fields Too Large", false];
    readonly 431: readonly ["Request Header Fields Too Large", false];
    readonly 440: readonly ["Login Time-out", false];
    readonly 444: readonly ["No Response", false];
    readonly 449: readonly ["Retry With", false];
    readonly 450: readonly ["Blocked by Windows Parental Controls", false];
    readonly 451: readonly ["Unavailable For Legal Reasons", false];
    readonly 494: readonly ["Request Header Too Large", false];
    readonly 495: readonly ["SSL Certificate Error", false];
    readonly 496: readonly ["SSL Certificate Required", false];
    readonly 497: readonly ["HTTP Request Sent to HTTPS Port", false];
    readonly 498: readonly ["Invalid Token", false];
    readonly 499: readonly ["Client Error", false];
    readonly '5XX': readonly ["Server Error", false];
    readonly 500: readonly ["Internal Server Error", false];
    readonly 501: readonly ["Not Implemented", false];
    readonly 502: readonly ["Bad Gateway", false];
    readonly 503: readonly ["Service Unavailable", false];
    readonly 504: readonly ["Gateway Timeout", false];
    readonly 505: readonly ["HTTP Version Not Supported", false];
    readonly 506: readonly ["Variant Also Negotiates", false];
    readonly 507: readonly ["Insufficient Storage", false];
    readonly 508: readonly ["Loop Detected", false];
    readonly 509: readonly ["Bandwidth Limit Exceeded", false];
    readonly 510: readonly ["Not Extended", false];
    readonly 511: readonly ["Network Authentication Required", false];
    readonly 520: readonly ["Web Server Returned an Unknown Error", false];
    readonly 521: readonly ["Web Server Is Down", false];
    readonly 522: readonly ["Connection Timed Out", false];
    readonly 523: readonly ["Origin Is Unreachable", false];
    readonly 524: readonly ["A Timeout Occurred", false];
    readonly 525: readonly ["SSL Handshake Failed", false];
    readonly 526: readonly ["Invalid SSL Certificate", false];
    readonly 527: readonly ["Railgun Error", false];
    readonly 529: readonly ["Site is Overloaded", false];
    readonly 530: readonly ["Site is Frozen", false];
    readonly 598: readonly ["Network Read Timeout Error", false];
};
/**
 * Returns whether the provided status code is valid or not.
 */
export declare function isStatusCodeValid(code: string | number): boolean;
/**
 * Returns an object containing information about the provided status code.
 * @example
 * getStatusCode(400)
 * -> {
 *   code: 400,
 *   message: 'Bad Request',
 *   success: false,
 * }
 */
export declare function getStatusCode(code: string | number): {
    code: string | 100 | 101 | 102 | 103 | 200 | 201 | 202 | 203 | 204 | 205 | 206 | 207 | 208 | 218 | 226 | 300 | 301 | 302 | 303 | 304 | 305 | 306 | 307 | 308 | 400 | 401 | 402 | 403 | 404 | 405 | 406 | 407 | 408 | 409 | 410 | 411 | 412 | 413 | 414 | 415 | 416 | 417 | 418 | 419 | 420 | 421 | 422 | 423 | 424 | 425 | 426 | 428 | 429 | 430 | 431 | 440 | 444 | 449 | 450 | 451 | 494 | 495 | 496 | 497 | 498 | 499 | 500 | 501 | 502 | 503 | 504 | 505 | 506 | 507 | 508 | 509 | 510 | 511 | 520 | 521 | 522 | 523 | 524 | 525 | 526 | 527 | 529 | 530 | 598;
    message: "Default" | "Informational" | "Continue" | "Switching Protocols" | "Processing" | "Early Hints" | "Success" | "OK" | "Created" | "Accepted" | "Non-Authoritative Information" | "No Content" | "Reset Content" | "Partial Content" | "Multi-Status" | "Already Reported" | "This is fine" | "IM Used" | "Redirection" | "Multiple Choices" | "Moved Permanently" | "Found" | "See Other" | "Not Modified" | "Use Proxy" | "Switch Proxy" | "Temporary Redirect" | "Permanent Redirect" | "Client Error" | "Bad Request" | "Unauthorized" | "Payment Required" | "Forbidden" | "Not Found" | "Method Not Allowed" | "Not Acceptable" | "Proxy Authentication Required" | "Request Timeout" | "Conflict" | "Gone" | "Length Required" | "Precondition Failed" | "Payload Too Large" | "URI Too Long" | "Unsupported Media Type" | "Range Not Satisfiable" | "Expectation Failed" | "I'm a teapot" | "Page Expired" | "Enhance Your Calm" | "Misdirected Request" | "Unprocessable Entity" | "Locked" | "Failed Dependency" | "Too Early" | "Upgrade Required" | "Precondition Required" | "Too Many Requests" | "Request Header Fields Too Large" | "Login Time-out" | "No Response" | "Retry With" | "Blocked by Windows Parental Controls" | "Unavailable For Legal Reasons" | "Request Header Too Large" | "SSL Certificate Error" | "SSL Certificate Required" | "HTTP Request Sent to HTTPS Port" | "Invalid Token" | "Server Error" | "Internal Server Error" | "Not Implemented" | "Bad Gateway" | "Service Unavailable" | "Gateway Timeout" | "HTTP Version Not Supported" | "Variant Also Negotiates" | "Insufficient Storage" | "Loop Detected" | "Bandwidth Limit Exceeded" | "Not Extended" | "Network Authentication Required" | "Web Server Returned an Unknown Error" | "Web Server Is Down" | "Connection Timed Out" | "Origin Is Unreachable" | "A Timeout Occurred" | "SSL Handshake Failed" | "Invalid SSL Certificate" | "Railgun Error" | "Site is Overloaded" | "Site is Frozen" | "Network Read Timeout Error";
    success: boolean;
};
/**
 * Returns a string containing the provided status code and message.
 * @example
 * getStatusCodeMessage('1XX') -> "1XX Informational"
 */
export declare function getStatusCodeMessage(code: string | number): string;
/**
 * Returns whether the provided status code is a successful status or not.
 * @example
 * isStatusCodeSuccessful(200) -> true
 */
export declare function isStatusCodeSuccessful(code: string | number): boolean;
